#ifndef SEEN_SP_GRADIENT_SPREAD_H
#define SEEN_SP_GRADIENT_SPREAD_H

enum SPGradientSpread {
    SP_GRADIENT_SPREAD_PAD,
    SP_GRADIENT_SPREAD_REFLECT,
    SP_GRADIENT_SPREAD_REPEAT,
    SP_GRADIENT_SPREAD_UNDEFINED = INT_MAX
};


#endif /* !SEEN_SP_GRADIENT_SPREAD_H */

/*
  Local Variables:
  mode:c++
  c-file-style:"stroustrup"
  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
  indent-tabs-mode:nil
  fill-column:99
  End:
*/
// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:fileencoding=utf-8:textwidth=99 :
